summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmxmlparser.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-19 19:03:33 +0000
commite69e8b1d09fb579316595b4e6a850e717358a8b1 (patch)
treea24fc20865f65772f530d16177520190594ffdd2 /kpovmodeler/pmxmlparser.h
parenteecec9afb81fdebb0f22e9da22635874c403f854 (diff)
downloadtdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.tar.gz
tdegraphics-e69e8b1d09fb579316595b4e6a850e717358a8b1.zip
TQt4 port kdegraphics
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1237557 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kpovmodeler/pmxmlparser.h')
-rw-r--r--kpovmodeler/pmxmlparser.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kpovmodeler/pmxmlparser.h b/kpovmodeler/pmxmlparser.h
index 2ff8f351..d33ff434 100644
--- a/kpovmodeler/pmxmlparser.h
+++ b/kpovmodeler/pmxmlparser.h
@@ -70,10 +70,10 @@ private:
bool initDocument( );
/**
* Looks for child objects, parses them and appends them to the parent
* object. If parent is 0, all objects are appended to the result list.
*/
- void parseChildObjects( TQDomElement& e, PMObject* parent );
+ void parseChildObjects( TQDomElement& e, PMObject* tqparent );
TQDomDocument* m_pDoc;
int m_majorDocumentFormat;
@@ -70,10 +70,10 @@ private:
bool initDocument( );
/**
- * Looks for child objects, parses them and appends them to the parent
- * object. If parent is 0, all objects are appended to the result list.
+ * Looks for child objects, parses them and appends them to the tqparent
+ * object. If tqparent is 0, all objects are appended to the result list.
*/